<?php

namespace Litecms\CurrencySettings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CurrencySettings\Models\Currency;

class CurrencyPolicy
{

    /**
     * Determine if the given user can view the currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function view(UserPolicy $user, Currency $currency)
    {
        if ($user->canDo('currency_settings.currency.view') && $user->isAdmin()) {
            return true;
        }

        return $currency->user_id == user_id() && $currency->user_type == user_type();
    }

    /**
     * Determine if the given user can create a currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('currency_settings.currency.create');
    }

    /**
     * Determine if the given user can update the given currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function update(UserPolicy $user, Currency $currency)
    {
        if ($user->canDo('currency_settings.currency.edit') && $user->isAdmin()) {
            return true;
        }

        return $currency->user_id == user_id() && $currency->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Currency $currency)
    {
        return $currency->user_id == user_id() && $currency->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Currency $currency)
    {
        if ($user->canDo('currency_settings.currency.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given currency.
     *
     * @param UserPolicy $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Currency $currency)
    {
        if ($user->canDo('currency_settings.currency.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
